==> ACE%2BTAO-5.8.3.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_component.h <==
/* -*- c++ -*- */

//=============================================================================
/**
 *  @file    be_visitor_component.h
 *
 *  $Id: be_visitor_component.h 92289 2010-10-20 19:53:11Z parsons $
 *
 *  Concrete visitors for the Component class
 *
 *
 *  @author Jeff Parsons
 */
//=============================================================================

#ifndef TAO_BE_VISITOR_COMPONENT_H
#define TAO_BE_VISITOR_COMPONENT_H

#include "be_visitor_interface.h"
#include "be_visitor_component_scope.h"

#include "be_visitor_component/component.h"
#include "be_visitor_component/component_svh.h"
#include "be_visitor_component/facet_svh.h"
#include "be_visitor_component/context_svh.h"
#include "be_visitor_component/servant_svh.h"
#include "be_visitor_component/component_svs.h"
#include "be_visitor_component/facet_svs.h"
#include "be_visitor_component/context_svs.h"
#include "be_visitor_component/servant_svs.h"
#include "be_visitor_component/component_ex_idl.h"
#include "be_visitor_component/facet_ex_idl.h"
#include "be_visitor_component/executor_ex_idl.h"
#include "be_visitor_component/context_ex_idl.h"
#include "be_visitor_component/component_exh.h"
#include "be_visitor_component/facet_exh.h"
#include "be_visitor_component/executor_private_exh.h"
#include "be_visitor_component/executor_exh.h"
#include "be_visitor_component/component_exs.h"
#include "be_visitor_component/facet_exs.h"
#include "be_visitor_component/executor_exs.h"
#include "be_visitor_component/executor_exs_attr_init.h"

#endif /* TAO_BE_VISITOR_COMPONENT_H */

==> ACE%2BTAO-6.2.3.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_component.h <==
/* -*- c++ -*- */

//=============================================================================
/**
 *  @file    be_visitor_component.h
 *
 *  $Id: be_visitor_component.h 95291 2011-12-12 08:52:52Z johnnyw $
 *
 *  Concrete visitors for the Component class
 *
 *
 *  @author Jeff Parsons
 */
//=============================================================================

#ifndef TAO_BE_VISITOR_COMPONENT_H
#define TAO_BE_VISITOR_COMPONENT_H

#include "be_visitor_interface.h"
#include "be_visitor_component_scope.h"

#include "be_visitor_component/component.h"
#include "be_visitor_component/component_svh.h"
#include "be_visitor_component/component_svth.h"
#include "be_visitor_component/context_svth.h"
#include "be_visitor_component/servant_svh.h"
#include "be_visitor_component/component_svs.h"
#include "be_visitor_component/component_svts.h"
#include "be_visitor_component/context_svts.h"
#include "be_visitor_component/servant_svs.h"
#include "be_visitor_component/component_ex_idl.h"
#include "be_visitor_component/executor_ex_idl.h"
#include "be_visitor_component/context_ex_idl.h"
#include "be_visitor_component/component_exh.h"
#include "be_visitor_component/facet_exh.h"
#include "be_visitor_component/executor_private_exh.h"
#include "be_visitor_component/executor_exh.h"
#include "be_visitor_component/component_exs.h"
#include "be_visitor_component/facet_exs.h"
#include "be_visitor_component/executor_exs.h"
#include "be_visitor_component/executor_exs_attr_init.h"
#include "be_visitor_component/component_ami_rh_ex_base.h"
#include "be_visitor_component/component_ami_rh_exh.h"
#include "be_visitor_component/component_ami_rh_exs.h"

#endif /* TAO_BE_VISITOR_COMPONENT_H */
